@@ -13,13 +13,13 @@ Email::MIME - Easy MIME message parsing.
 
 =head1 VERSION
 
-version 1.856
+version 1.858
 
- $Id: /my/pep/Email-MIME/trunk/lib/Email/MIME.pm 28543 2006-11-28T01:51:37.957759Z rjbs  $
+ $Id: /my/pep/Email-MIME/trunk/lib/Email/MIME.pm 30662 2007-02-10T03:50:21.916382Z rjbs  $
 
 =cut
 
-our $VERSION = '1.856';
+our $VERSION = '1.858';
 
 sub new {
     my $self = shift->SUPER::new(@_);
@@ -37,9 +37,8 @@ sub as_string {
 
 sub parts {
     my $self = shift;
-    if (!$self->{parts}) {
-      $self->fill_parts;
-    }
+
+    $self->fill_parts unless $self->{parts};
 
     my @parts = @{$self->{parts}};
        @parts = $self unless @parts;
@@ -61,7 +60,7 @@ sub fill_parts {
 
 sub body {
     my $self = shift;
-    my $body = $self->{body};
+    my $body = $self->SUPER::body;
     my $cte = $self->header("Content-Transfer-Encoding");
     return $body unless $cte;
     if (!$self->force_decode_hook and $cte =~ /^7bit|8bit|binary/i) {
@@ -91,17 +90,29 @@ sub parts_multipart {
     return $self->parts_single_part unless $boundary;
 
     $self->{body_raw} = $self->SUPER::body;
+
     # rfc1521 7.2.1
     my ($body, $epilogue)
       = split /^--\Q$boundary\E--\s*$/sm, $self->body_raw, 2;
 
     my @bits = split /^--\Q$boundary\E\s*$/sm, ($body||'');
-    delete $self->{body};
+
+    $self->SUPER::body_set(undef);
 
     # This is a horrible hack, although it's debateable whether it was better
     # or worse when it was $self->{body} = shift @bits ... -- rjbs, 2006-11-27
     $self->SUPER::body_set(shift @bits) if ($bits[0]||'') !~ /.*:.*/;
-    $self->{parts} = [ map { (ref $self)->new($_) } @bits ];
+
+    my $bits = @bits;
+
+    my @parts;
+    for my $bit (@bits) {
+      $bit =~ s/\A[\n\r]+//smg;
+      my $email = (ref $self)->new($bit);
+      push @parts, $email;
+    }
+
+    $self->{parts} = \@parts;
 
     return @{$self->{parts}};
 }
@@ -174,7 +185,7 @@ __END__
   use Email::MIME;
   my $parsed = Email::MIME->new($message);
 
-  my Email::MIME @parts = $parsed->parts;
+  my @parts = $parsed->parts; # These will be Email::MIME objects, too.
   my $decoded = $parsed->body;
   my $non_decoded = $parsed->body_raw;
 
